#!/usr/bin/env python3
"""
binhop is a visualization tool for binwalk.
it might help you find silent failures to extract files.
"""
import argparse
from .core import process_file


def main() -> None:
    """
    Execute binhop, a visualization tool for binwalk, on the specified input blob.

    Usage:
        binhop [INPUT_FILE]

    Arguments:
        INPUT_FILE      Optional path to the binary file to analyze or blank for STDIN.

    Returns:
        None
    """
    parser = argparse.ArgumentParser(description=__doc__)

    parser.add_argument(
        "file",
        nargs="?",
        default="-",
        metavar="INPUT_FILE",
        type=argparse.FileType("r"),
        help="path to target binary (or omit for STDIN)",
    )

    args = parser.parse_args()
    process_file(args.file)

    try:
        args.file.close()
    except ValueError:
        # Continue if the file handle already closed
        pass


if __name__ == "__main__":
    main()
